@@ -1,7 +1,7 @@
 package App::DateUtils;
 
-our $DATE = '2016-06-19'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2016-06-28'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -86,11 +86,19 @@ sub parse_date {
     my @res;
     for my $date (@{ $args{dates} }) {
         my $rec = { original => $date };
-        if ($mod =~ /^DateTime::Format::(Alami|Natural)/) {
+        if ($mod =~ /^DateTime::Format::Alami/) {
+            my $res = $parser->parse_datetime($date, {format=>'combined'});
+            if ($res->{DateTime}) {
+                $rec->{is_parseable} = 1;
+                $rec->{as_epoch} = $res->{epoch};
+                $rec->{as_datetime_obj} = "$res->{DateTime}";
+                $rec->{pattern} = $res->{pattern};
+            } else {
+                $rec->{is_parseable} = 0;
+            }
+        } elsif ($mod =~ /^DateTime::Format::Natural/) {
             my $dt = $parser->parse_datetime($date);
-            my $success = $mod =~ /Alami/ ? $dt : $parser->success;
-
-            if ($success) {
+            if ($parser->{success}) {
                 $rec->{is_parseable} = 1;
                 $rec->{as_epoch} = $dt->epoch;
                 $rec->{as_datetime_obj} = "$dt";
@@ -334,7 +342,7 @@ App::DateUtils - An assortment of date-/time-related CLI utilities
 
 =head1 VERSION
 
-This document describes version 0.05 of App::DateUtils (from Perl distribution App-DateUtils), released on 2016-06-19.
+This document describes version 0.06 of App::DateUtils (from Perl distribution App-DateUtils), released on 2016-06-28.
 
 =head1 SYNOPSIS
 
@@ -374,7 +382,7 @@ Examples:
 
 =item * Convert "today" to epoch:
 
- dateconv(date => "today"); # -> 1466294400
+ dateconv(date => "today"); # -> 1467072000
 
 =item * Convert epoch to ymd:
 
@@ -444,18 +452,8 @@ Result:
    200,
    "OK",
    [
-     {
-       as_datetime_obj => "2015-09-23T00:00:00",
-       as_epoch        => 1442966400,
-       is_parseable    => 1,
-       original        => "23 sep 2015",
-     },
-     {
-       as_datetime_obj => "2016-06-20T00:00:00",
-       as_epoch        => 1466380800,
-       is_parseable    => 1,
-       original        => "tomorrow",
-     },
+     { is_parseable => 0, original => "23 sep 2015" },
+     { is_parseable => 0, original => "tomorrow" },
      { is_parseable => 0, original => "foo" },
    ],
    {},
